"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.takeOverPost = exports.removePostLock = exports.refreshPostLock = exports.reorderPosts = exports.duplicatePost = exports.emptyTrash = exports.deletePost = exports.updatePost = exports.getPost = exports.addPost = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _services = require("../services");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const addPost = async (args, dispatch, config) => {
  const result = await _services.postServices.addPost(args, dispatch, config);

  if (result) {
    dispatch({
      type: "ADD_POST",
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
  }

  return result;
};

exports.addPost = addPost;

const getPost = async (args, dispatch, config) => {
  const result = await _services.postServices.getPost(args, dispatch, config);
  return result;
};

exports.getPost = getPost;

const updatePost = async (args, dispatch, config) => {
  const result = await _services.postServices.updatePost(args, dispatch, config);

  if (result) {
    dispatch({
      type: "ADD_POST",
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
    dispatch({
      type: "ADD_EDITOR_POST",
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
  }

  return result;
};

exports.updatePost = updatePost;

const deletePost = async (_ref, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref;
  const result = await _services.postServices.deletePost({
    siteID,
    id
  }, dispatch, config);

  if (result) {
    dispatch({
      type: "DELETE_POST",
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID
      })
    });
  }

  return result;
};

exports.deletePost = deletePost;

const emptyTrash = async (args, dispatch, config) => {
  const result = await _services.postServices.emptyTrash(args, dispatch, config);

  if (result) {
    dispatch({
      type: "DELETE_POSTS",
      payload: {
        posts: result,
        siteID: args.siteID
      }
    });
  }

  return result;
};

exports.emptyTrash = emptyTrash;

const duplicatePost = async (_ref2, dispatch, config) => {
  let {
    siteID,
    id
  } = _ref2;
  const result = await _services.postServices.duplicatePost({
    siteID,
    id
  }, dispatch, config);

  if (result) {
    dispatch({
      type: "ADD_POST",
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID
      })
    });
  }

  return result;
};

exports.duplicatePost = duplicatePost;

const reorderPosts = async (_ref3, dispatch, config) => {
  let {
    siteID,
    postType,
    posts
  } = _ref3;
  const postIDs = posts.reduce((ac, a) => _objectSpread(_objectSpread({}, ac), {}, {
    [a.id]: a.order
  }), {}); // We're not gonna wait until the function is completed to give the user an instant feedback

  _services.postServices.reorderPosts({
    siteID,
    postIDs
  }, dispatch, config);

  dispatch({
    type: 'UPDATE_COLLECTION',
    payload: _objectSpread(_objectSpread({
      siteID
    }, postType), {}, {
      posts: posts.reduce((ac, a) => _objectSpread(_objectSpread({}, ac), {}, {
        [a.id]: a
      }), {})
    })
  });
};

exports.reorderPosts = reorderPosts;

const refreshPostLock = async (args, dispatch, config) => {
  var _result$locked;

  const result = await _services.postServices.refreshPostLock(args, dispatch, config); // If the property locked is set in the result, it means someone took over the post and we need to disable editing for the current user

  if (result !== null && result !== void 0 && (_result$locked = result.locked) !== null && _result$locked !== void 0 && _result$locked.id) {
    dispatch({
      type: 'ADD_POST',
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
    dispatch({
      type: 'ADD_EDITOR_POST',
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
  }

  return result;
};

exports.refreshPostLock = refreshPostLock;

const removePostLock = async (args, dispatch, config) => {
  const result = await _services.postServices.removePostLock(args, dispatch, config);
  return result;
};

exports.removePostLock = removePostLock;

const takeOverPost = async (args, dispatch, config) => {
  const result = await _services.postServices.takeOverPost(args, dispatch, config);

  if (result) {
    dispatch({
      type: 'CLOSE_DIALOG'
    });
    dispatch({
      type: 'ADD_POST',
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
    dispatch({
      type: 'ADD_EDITOR_POST',
      payload: _objectSpread(_objectSpread({}, result), {}, {
        siteID: args.siteID
      })
    });
  }

  return result;
};

exports.takeOverPost = takeOverPost;