"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _router = require("@reach/router");

var _immer = _interopRequireDefault(require("immer"));

var _antd = require("antd");

var _lodash = require("lodash");

var _icons = require("@ant-design/icons");

var _EditorFields = _interopRequireDefault(require("./EditorFields"));

var _Input = _interopRequireDefault(require("./Input"));

var _Select = _interopRequireDefault(require("./Select"));

var _Caption = _interopRequireDefault(require("./Caption"));

var _PostTreeSelect = _interopRequireDefault(require("./PostTreeSelect"));

var _MediaLibrary = _interopRequireDefault(require("./MediaLibrary"));

var _FilePicker = _interopRequireDefault(require("./editorFields/FilePicker"));

var _actions = require("../actions");

var _store = require("../store");

var _theme = require("../theme");

var _utils = require("../utils");

var _routes = _interopRequireDefault(require("../routes"));

var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const EditorSidebar = props => {
  var _sites$siteID2, _sites$siteID2$editor, _authUser$capabilitie, _fields$themeOptions, _fields$themeOptions$;

  const {
    editable,
    onToggleSidebar
  } = props,
        rest = (0, _objectWithoutProperties2.default)(props, ["editable", "onToggleSidebar"]);
  const [{
    config,
    authState: {
      authUser
    },
    cmsState: {
      sites,
      siteID
    },
    editorState: {
      site,
      post,
      siteHasChanged,
      postHasChanged
    }
  }, dispatch] = (0, _store.useStore)();
  const {
    fields
  } = config;
  const [loading, setLoading] = (0, _react.useState)(null);
  const [sidebar, setSidebar] = (0, _react.useState)('content');
  const [expiryDate, setExpiryDate] = (0, _react.useState)(48);
  const [previewLink, setPreviewLink] = (0, _react.useState)(null);

  const handleChangePost = (name, value) => {
    const nextPost = (0, _immer.default)(post, draft => {
      (0, _lodash.set)(draft, "".concat(name), value);

      if (name === 'template') {
        (0, _lodash.set)(draft, 'content', {});
      }

      return draft;
    });
    dispatch({
      type: 'UPDATE_EDITOR_POST',
      payload: nextPost
    });
  };

  const handleSelectRevision = async postID => {
    setLoading(postID);
    const result = await _actions.postActions.getPost({
      siteID,
      postID
    }, dispatch, config);

    if (result) {
      // Update existing post with title, content, post date and revisionID.
      const {
        content,
        title,
        revisionID
      } = result;
      dispatch({
        type: 'UPDATE_EDITOR_POST',
        payload: _objectSpread(_objectSpread({}, post), {}, {
          content,
          title,
          revisionID,
          siteID
        })
      });
    }

    setLoading(null);
  };

  const handleChangeSite = (name, value) => {
    const nextSite = (0, _immer.default)(site, draft => (0, _lodash.set)(draft, "".concat(name), value));
    dispatch({
      type: 'UPDATE_EDITOR_SITE',
      payload: nextSite
    });
  };

  const handleSelectImage = (name, image) => {
    handleChangePost(name, image);
    dispatch({
      type: 'CLOSE_DIALOG'
    });
  };

  const handleChangeContent = field => {
    if (field.global) {
      const nextSite = (0, _immer.default)(site, draft => {
        return (0, _lodash.set)(draft, "themeOptions.".concat(field.id), field);
      });
      dispatch({
        type: 'UPDATE_EDITOR_SITE',
        payload: nextSite
      });
    } else {
      const nextPost = (0, _immer.default)(post, draft => {
        return (0, _lodash.set)(draft, "content.".concat(field.id), field);
      });
      dispatch({
        type: 'UPDATE_EDITOR_POST',
        payload: nextPost
      });
    }
  };

  const handleSaveDraft = () => {
    handleSave('draft', 'draft');
  };

  const handlePublish = () => {
    handleSave('publish', 'publish');
  };

  const handleUpdate = status => {
    handleSave('update', status);
  };

  const handleSave = async (action, status) => {
    var _config$settings;

    const {
      id,
      themeOptions,
      frontPage
    } = site; // Trigger dummy message to give user feedback

    if (!siteHasChanged && !postHasChanged && post.status === status) {
      return _antd.message.success('Updated successfully');
    }

    let templateObject = (0, _utils.getTemplateByPost)(post, fields); // Nullify template object if syncing is disabled or not in development mode

    if ((config === null || config === void 0 ? void 0 : (_config$settings = config.settings) === null || _config$settings === void 0 ? void 0 : _config$settings.sync) === false || process.env.NODE_ENV !== 'development') {
      templateObject = null;
    }

    setLoading(action); // Reset preview link so it can be regenerated.

    setPreviewLink(null);
    let postResult, siteResult;

    if (siteHasChanged) {
      siteResult = await _actions.siteActions.updateSite({
        id,
        themeOptions,
        frontPage
      }, dispatch, config);
    }

    if (postHasChanged || action === 'publish') {
      postResult = await _actions.postActions.updatePost(_objectSpread(_objectSpread({
        siteID: id
      }, post), {}, {
        status,
        templateObject
      }), dispatch, config); // In case the user only updates the post, the new deployment status isn't available (only for site updates), so we need to manually update the site.

      if (!siteHasChanged) {
        dispatch({
          type: 'ADD_SITE_SETTING',
          payload: {
            id: siteID,
            key: 'deployment.undeployedChanges',
            value: true
          }
        });
      }
    }

    setLoading('');

    if (postResult || siteResult) {
      _antd.message.success('Updated successfully'); // We need to generate the slug and navigate to it in case the user has changed the post name or set a new front page


      const nextPostType = (0, _immer.default)(sites[siteID].postTypes[post.postTypeID], draft => {
        return (0, _lodash.set)(draft, "posts.".concat(post.id), post);
      });
      const slug = (0, _utils.generateSlug)(nextPostType, post.id, sites[siteID].frontPage, true);
      (0, _router.navigate)(slug);
    }
  };

  const handleGeneratePreviewLink = async () => {
    const result = await _actions.previewActions.generatePreviewLink({
      siteID,
      postID: post.id,
      expiryDate
    }, dispatch, config);

    if (result) {
      setPreviewLink(result);
    }
  };

  const renderContent = () => {
    const template = (0, _utils.getTemplateByPost)(post, fields); // TODO: Very similar setup to utils function 'formatFieldsToProps'.
    // There might be a chance to unify the function.

    const formattedFields = template !== null && template !== void 0 && template.fields ? template.fields.map(o => {
      let field;

      if (o.global) {
        var _site$themeOptions, _site$themeOptions$o$;

        // Use field from themeOptions (single source of truth) and add value from site state
        field = _objectSpread(_objectSpread({}, fields === null || fields === void 0 ? void 0 : fields.themeOptions.find(p => p.id === o.id)), {}, {
          value: site === null || site === void 0 ? void 0 : (_site$themeOptions = site.themeOptions) === null || _site$themeOptions === void 0 ? void 0 : (_site$themeOptions$o$ = _site$themeOptions[o.id]) === null || _site$themeOptions$o$ === void 0 ? void 0 : _site$themeOptions$o$.value
        });
      } else {
        var _post$content;

        field = (post === null || post === void 0 ? void 0 : (_post$content = post.content) === null || _post$content === void 0 ? void 0 : _post$content[o.id]) || o;
      }

      const formattedField = (0, _utils.formatFieldForEditor)({
        field,
        site
      });
      return _objectSpread(_objectSpread(_objectSpread({
        global: o.global
      }, field), o), {}, {
        value: formattedField === null || formattedField === void 0 ? void 0 : formattedField.value
      });
    }) : [];
    return /*#__PURE__*/_react.default.createElement(EditorFieldsContainer, null, /*#__PURE__*/_react.default.createElement(_EditorFields.default, {
      fields: formattedFields,
      onChangeElement: handleChangeContent
    }));
  };

  const renderThemeSettings = () => {
    // Loop over global options (only source of truth)
    const formattedFields = fields === null || fields === void 0 ? void 0 : fields.themeOptions.filter(o => !o.hide).map(o => {
      var _site$themeOptions2;

      const formattedField = (0, _utils.formatFieldForEditor)({
        // Pass in fields from editor site state or global option itself
        field: (site === null || site === void 0 ? void 0 : (_site$themeOptions2 = site.themeOptions) === null || _site$themeOptions2 === void 0 ? void 0 : _site$themeOptions2[o.id]) || o,
        site
      });
      return _objectSpread(_objectSpread({
        global: true
      }, o), {}, {
        value: formattedField === null || formattedField === void 0 ? void 0 : formattedField.value
      });
    });
    return /*#__PURE__*/_react.default.createElement(EditorFieldsContainer, null, /*#__PURE__*/_react.default.createElement(_EditorFields.default, {
      fields: formattedFields,
      onChangeElement: handleChangeContent
    }));
  };

  const renderSettings = () => {
    var _sites$siteID, _sites$siteID$postTyp, _fields$postTypes, _fields$postTypes$pos;

    const postType = (_sites$siteID = sites[siteID]) === null || _sites$siteID === void 0 ? void 0 : (_sites$siteID$postTyp = _sites$siteID.postTypes) === null || _sites$siteID$postTyp === void 0 ? void 0 : _sites$siteID$postTyp[post === null || post === void 0 ? void 0 : post.postTypeID];
    const postTypeTemplates = fields === null || fields === void 0 ? void 0 : (_fields$postTypes = fields.postTypes) === null || _fields$postTypes === void 0 ? void 0 : (_fields$postTypes$pos = _fields$postTypes[post === null || post === void 0 ? void 0 : post.postTypeID]) === null || _fields$postTypes$pos === void 0 ? void 0 : _fields$postTypes$pos.templates;
    const postTypeTemplatesArray = postTypeTemplates ? Object.values(postTypeTemplates).filter(o => o.id !== 'archive') : []; // Get all templates with id 'archive'

    const archiveTemplatesArray = [];

    if ((post === null || post === void 0 ? void 0 : post.postTypeID) === 'page' && fields !== null && fields !== void 0 && fields.postTypes) {
      Object.values(fields === null || fields === void 0 ? void 0 : fields.postTypes).map(o => (o === null || o === void 0 ? void 0 : o.templates) && Object.values(o.templates).map(p => p.id === 'archive' && archiveTemplatesArray.push(p)));
    }

    return /*#__PURE__*/_react.default.createElement(Content, null, /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical",
      size: 20
    }, /*#__PURE__*/_react.default.createElement(_Input.default, {
      value: (post === null || post === void 0 ? void 0 : post.title) || '',
      onChange: e => handleChangePost('title', e.target.value),
      label: 'Title'
    }), /*#__PURE__*/_react.default.createElement(_Input.default, {
      value: (post === null || post === void 0 ? void 0 : post.id) === (site === null || site === void 0 ? void 0 : site.frontPage) ? '/' : (post === null || post === void 0 ? void 0 : post.slug) || '',
      onChange: e => handleChangePost('slug', e.target.value),
      label: 'Slug',
      disabled: (post === null || post === void 0 ? void 0 : post.id) === (site === null || site === void 0 ? void 0 : site.frontPage)
    }), (postTypeTemplatesArray.length > 1 || archiveTemplatesArray.length > 0) && /*#__PURE__*/_react.default.createElement(_Select.default, {
      value: post === null || post === void 0 ? void 0 : post.template,
      onChange: value => handleChangePost('template', value),
      label: 'Template'
    }, (postTypeTemplatesArray.length > 1 || archiveTemplatesArray.length > 0) && /*#__PURE__*/_react.default.createElement(_antd.Select.OptGroup, {
      label: 'Single'
    }, postTypeTemplatesArray.map(o => /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      key: o.id,
      value: o.id,
      children: o.label || o.id
    }))), archiveTemplatesArray.length > 0 && /*#__PURE__*/_react.default.createElement(_antd.Select.OptGroup, {
      label: 'Archive'
    }, archiveTemplatesArray.map(o => {
      const id = "archive-".concat(o.postTypeID);
      return /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
        key: id,
        value: id,
        children: o.label
      });
    }))), /*#__PURE__*/_react.default.createElement(_Select.default, {
      value: (post === null || post === void 0 ? void 0 : post.status) || '',
      onChange: value => handleChangePost('status', value),
      label: 'Status'
    }, /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 'publish',
      children: 'Publish'
    }), /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 'draft',
      children: 'Draft'
    }), /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 'trash',
      children: 'Trash'
    })), (post === null || post === void 0 ? void 0 : post.postTypeID) === 'page' && post.id !== (site === null || site === void 0 ? void 0 : site.frontPage) && /*#__PURE__*/_react.default.createElement(_PostTreeSelect.default, {
      label: "Parent",
      items: Object.values(postType.posts).filter(o => o.id !== post.id),
      value: post === null || post === void 0 ? void 0 : post.parentID,
      onChange: value => handleChangePost('parentID', value)
    }), (post === null || post === void 0 ? void 0 : post.taxonomies) && Object.keys(post.taxonomies).filter(k => {
      var _config$fields, _config$fields$taxono;

      return !!(config !== null && config !== void 0 && (_config$fields = config.fields) !== null && _config$fields !== void 0 && (_config$fields$taxono = _config$fields.taxonomies) !== null && _config$fields$taxono !== void 0 && _config$fields$taxono.find(o => o.id === k));
    }).map(k => {
      const o = sites[siteID].taxonomies[k];
      return o && /*#__PURE__*/_react.default.createElement(_Select.default, {
        key: k,
        onChange: v => handleChangePost("taxonomies.".concat(k), v),
        allowClear: true,
        placeholder: "Select category",
        mode: "multiple",
        label: o.title,
        defaultValue: post.taxonomies[k]
      }, o.terms && o.terms.map(p => {
        return /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
          key: p.id,
          value: p.id,
          children: p.title
        });
      }));
    }), (post === null || post === void 0 ? void 0 : post.postTypeID) !== 'page' && /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical",
      size: 6
    }, /*#__PURE__*/_react.default.createElement(_Caption.default, {
      children: "Featured Image"
    }), /*#__PURE__*/_react.default.createElement(_FilePicker.default, {
      value: post === null || post === void 0 ? void 0 : post.featuredImage,
      onRemove: () => handleSelectImage('featuredImage', null),
      onClick: () => dispatch({
        type: "SET_DIALOG",
        payload: {
          open: true,
          title: 'Media',
          component: /*#__PURE__*/_react.default.createElement(_MediaLibrary.default, {
            onSelect: v => handleSelectImage('featuredImage', v),
            allow: ['image']
          }),
          width: 1024
        }
      })
    })), (post === null || post === void 0 ? void 0 : post.postTypeID) === 'page' && /*#__PURE__*/_react.default.createElement(_antd.Checkbox, {
      value: post === null || post === void 0 ? void 0 : post.id,
      checked: (post === null || post === void 0 ? void 0 : post.id) === (site === null || site === void 0 ? void 0 : site.frontPage),
      onChange: e => handleChangeSite('frontPage', e.target.checked ? e.target.value : ''),
      children: "Set as Homepage"
    })));
  };

  const renderSeo = () => {
    var _post$seo, _post$seo2, _post$seo3;

    return /*#__PURE__*/_react.default.createElement(Content, null, /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical",
      size: 25
    }, /*#__PURE__*/_react.default.createElement(_Input.default, {
      value: (post === null || post === void 0 ? void 0 : (_post$seo = post.seo) === null || _post$seo === void 0 ? void 0 : _post$seo.title) || '',
      onChange: e => handleChangePost('seo.title', e.target.value),
      label: 'SEO Title'
    }), /*#__PURE__*/_react.default.createElement(_Input.default, {
      value: (post === null || post === void 0 ? void 0 : (_post$seo2 = post.seo) === null || _post$seo2 === void 0 ? void 0 : _post$seo2.metaDesc) || '',
      onChange: e => handleChangePost('seo.metaDesc', e.target.value),
      label: 'SEO Description',
      rows: 4
    }), /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical",
      size: 6
    }, /*#__PURE__*/_react.default.createElement(_Caption.default, {
      children: "Open Graph Image"
    }), /*#__PURE__*/_react.default.createElement(_FilePicker.default, {
      value: post === null || post === void 0 ? void 0 : (_post$seo3 = post.seo) === null || _post$seo3 === void 0 ? void 0 : _post$seo3.opengraphImage,
      onRemove: () => handleSelectImage('seo.opengraphImage', null),
      onClick: () => dispatch({
        type: "SET_DIALOG",
        payload: {
          open: true,
          title: 'Media',
          component: /*#__PURE__*/_react.default.createElement(_MediaLibrary.default, {
            onSelect: v => handleSelectImage('seo.opengraphImage', v),
            allow: ['image']
          }),
          width: 1024
        }
      })
    }))));
  };

  const renderRevisions = () => {
    var _post$revisions;

    return /*#__PURE__*/_react.default.createElement(Content, null, /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical"
    }, (post === null || post === void 0 ? void 0 : (_post$revisions = post.revisions) === null || _post$revisions === void 0 ? void 0 : _post$revisions.length) > 0 ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
      type: !post.revisionID ? 'primary' : 'default',
      onClick: () => !!post.revisionID && handleSelectRevision(post.id),
      children: 'Current version',
      loading: loading === post.id,
      block: true
    }), post.revisions.map(o => /*#__PURE__*/_react.default.createElement(_antd.Button, {
      key: o.id,
      type: o.id === post.revisionID ? 'primary' : 'default',
      onClick: () => o.id !== post.revisionID && handleSelectRevision(o.id),
      children: o.title,
      loading: loading === o.id,
      block: true
    }))) : /*#__PURE__*/_react.default.createElement(_antd.Empty, {
      style: {
        padding: 20
      },
      imageStyle: {
        height: 120
      },
      description: 'No Revisions'
    })));
  };

  const renderPreview = () => {
    return /*#__PURE__*/_react.default.createElement(Content, null, /*#__PURE__*/_react.default.createElement(_antd.Space, {
      direction: "vertical"
    }, (siteHasChanged || postHasChanged) && /*#__PURE__*/_react.default.createElement(_antd.Typography.Text, {
      type: "secondary"
    }, "Save the latest changes to include them in the preview."), /*#__PURE__*/_react.default.createElement(_Select.default, {
      value: expiryDate,
      onChange: value => setExpiryDate(value),
      label: 'Expiry date'
    }, /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 24,
      children: '1 Day'
    }), /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 48,
      children: '2 Days'
    }), /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 168,
      children: '1 Week'
    }), /*#__PURE__*/_react.default.createElement(_antd.Select.Option, {
      value: 720,
      children: '1 Month'
    })), previewLink ? /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
      children: "Copy to Clipboard",
      type: "primary",
      onClick: () => {
        navigator.clipboard.writeText(previewLink);

        _antd.message.success('Copied to Clipboard');
      },
      block: true
    }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
      children: "Open in new tab",
      onClick: () => window.open(previewLink, '_blank'),
      type: "primary",
      block: true
    })) : /*#__PURE__*/_react.default.createElement(_antd.Button, {
      children: "Generate Link",
      onClick: handleGeneratePreviewLink,
      type: "primary",
      block: true
    })));
  };

  return /*#__PURE__*/_react.default.createElement(Container, (0, _extends2.default)({
    id: "jam-cms-sidebar",
    sidebar: sites === null || sites === void 0 ? void 0 : (_sites$siteID2 = sites[siteID]) === null || _sites$siteID2 === void 0 ? void 0 : (_sites$siteID2$editor = _sites$siteID2.editorOptions) === null || _sites$siteID2$editor === void 0 ? void 0 : _sites$siteID2$editor.sidebar
  }, rest), /*#__PURE__*/_react.default.createElement(Header, null, /*#__PURE__*/_react.default.createElement(_antd.Row, {
    justify: "space-between"
  }, /*#__PURE__*/_react.default.createElement(_antd.Space, {
    size: 15
  }, /*#__PURE__*/_react.default.createElement(_antd.Popconfirm, {
    placement: "rightTop",
    title: "Are you sure to discard unsaved changes?",
    onConfirm: () => (0, _router.navigate)((0, _routes.default)("collection", {
      siteID,
      postTypeID: (post === null || post === void 0 ? void 0 : post.postTypeID) || 'page'
    })),
    disabled: !postHasChanged && !siteHasChanged
  }, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    icon: /*#__PURE__*/_react.default.createElement(_icons.HomeOutlined, null),
    type: "ghost",
    size: "small",
    ghost: true,
    onClick: () => {
      if (!postHasChanged && !siteHasChanged) {
        (0, _router.navigate)((0, _routes.default)("collection", {
          siteID,
          postTypeID: (post === null || post === void 0 ? void 0 : post.postTypeID) || 'page'
        }));
      }
    }
  }))), /*#__PURE__*/_react.default.createElement(_antd.Space, {
    size: 15
  }, (post === null || post === void 0 ? void 0 : post.status) === 'draft' && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    children: "Save Draft",
    onClick: handleSaveDraft,
    loading: loading === 'draft',
    size: "small",
    ghost: true
  }), /*#__PURE__*/_react.default.createElement(_antd.Button, {
    children: "Publish",
    onClick: handlePublish,
    loading: loading === 'publish',
    size: "small",
    ghost: true
  })), ((post === null || post === void 0 ? void 0 : post.status) === 'publish' || (post === null || post === void 0 ? void 0 : post.status) === 'trash') && /*#__PURE__*/_react.default.createElement(_antd.Button, {
    children: "Update",
    onClick: () => handleUpdate(post.status),
    loading: loading === 'update',
    size: "small",
    ghost: true
  })))), /*#__PURE__*/_react.default.createElement(TabsContainer, null, /*#__PURE__*/_react.default.createElement(_antd.Tabs, {
    activeKey: sidebar,
    tabBarGutter: 0,
    onChange: value => setSidebar(value)
  }, /*#__PURE__*/_react.default.createElement(_antd.Tabs.TabPane, {
    key: 'content',
    tab: 'Content',
    disabled: !editable
  }), /*#__PURE__*/_react.default.createElement(_antd.Tabs.TabPane, {
    key: 'settings',
    tab: 'Settings',
    disabled: !editable
  }), /*#__PURE__*/_react.default.createElement(_antd.Tabs.TabPane, {
    key: 'seo',
    tab: 'SEO',
    disabled: !editable
  })), /*#__PURE__*/_react.default.createElement(_antd.Dropdown.Button, {
    disabled: !editable,
    type: "text",
    overlay: /*#__PURE__*/_react.default.createElement(_antd.Menu, null, (post === null || post === void 0 ? void 0 : post.revisionsEnabled) && /*#__PURE__*/_react.default.createElement(_antd.Menu.Item, {
      key: "preview",
      onClick: () => setSidebar('preview')
    }, "Share Preview"), (authUser === null || authUser === void 0 ? void 0 : (_authUser$capabilitie = authUser.capabilities) === null || _authUser$capabilitie === void 0 ? void 0 : _authUser$capabilitie.edit_theme_options) && (fields === null || fields === void 0 ? void 0 : (_fields$themeOptions = fields.themeOptions) === null || _fields$themeOptions === void 0 ? void 0 : (_fields$themeOptions$ = _fields$themeOptions.filter(o => !o.hide)) === null || _fields$themeOptions$ === void 0 ? void 0 : _fields$themeOptions$.length) > 0 && /*#__PURE__*/_react.default.createElement(_antd.Menu.Item, {
      key: 'theme',
      onClick: () => setSidebar('theme')
    }, "Theme"), (post === null || post === void 0 ? void 0 : post.revisionsEnabled) && /*#__PURE__*/_react.default.createElement(_antd.Menu.Item, {
      key: "revisions",
      onClick: () => setSidebar('revisions')
    }, "Revisions"), /*#__PURE__*/_react.default.createElement(_antd.Menu.Item, {
      key: "sidebar",
      onClick: onToggleSidebar
    }, "Toggle Sidebar ", /*#__PURE__*/_react.default.createElement(_antd.Typography.Text, {
      keyboard: true
    }, "ESC")))
  })), /*#__PURE__*/_react.default.createElement(TabContainer, null, sidebar === 'content' && renderContent(), sidebar === 'settings' && renderSettings(), sidebar === 'seo' && renderSeo(), sidebar === 'revisions' && (post === null || post === void 0 ? void 0 : post.revisionsEnabled) && renderRevisions(), sidebar === 'theme' && renderThemeSettings(), sidebar === 'preview' && renderPreview()));
};

const Container = _styledComponents.default.div(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  position: fixed;\n  z-index: 1000;\n  left: ", ";\n  right: ", ";\n  top: 0;\n  width: ", ";\n  height: 100vh;\n  background: ", ";\n  border-right: 1px solid ", ";\n  box-shadow: 0 2.8px 2.2px rgba(0, 0, 0, 0.034), 0 6.7px 5.3px rgba(0, 0, 0, 0.048),\n    0 12.5px 10px rgba(0, 0, 0, 0.06), 0 22.3px 17.9px rgba(0, 0, 0, 0.072),\n    0 41.8px 33.4px rgba(0, 0, 0, 0.086), 0 100px 80px rgba(0, 0, 0, 0.12);\n\n  .ant-tabs > .ant-tabs-nav {\n    margin-bottom: 0;\n  }\n"])), (_ref) => {
  let {
    sidebar: {
      position
    }
  } = _ref;
  return position === 'left' ? 0 : 'unset';
}, (_ref2) => {
  let {
    sidebar: {
      position
    }
  } = _ref2;
  return position === 'left' ? 'unset' : 0;
}, (_ref3) => {
  let {
    sidebar: {
      width
    }
  } = _ref3;
  return "".concat(width, "px");
}, _theme.colors.secondaryContrast, _theme.colors.tertiary);

const Header = _styledComponents.default.div(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n  padding: 15px;\n  background: ", ";\n\n  button {\n    &:hover {\n      border-color: #fff;\n      background-color: #fff !important;\n    }\n  }\n"])), _theme.colors.primary);

const TabsContainer = _styledComponents.default.div(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  padding-right: 10px;\n  background: #fff;\n\n  .ant-tabs-nav-wrap {\n    padding: 0 15px;\n  }\n"])));

const TabContainer = _styledComponents.default.div(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["\n  overflow: auto;\n  white-space: pre-wrap;\n  height: calc(100vh - 95px);\n  scrollbar-width: thin;\n\n  &&::-webkit-scrollbar {\n    width: 8px;\n  }\n\n  &&::-webkit-scrollbar-track {\n    border-radius: 4px;\n  }\n\n  &&::-webkit-scrollbar-thumb {\n    border-radius: 4px;\n    background: ", ";\n  }\n"])), _theme.colors.tertiary);

const Content = _styledComponents.default.div(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["\n  padding: 15px;\n  min-height: calc(100% - 46px);\n"])));

const EditorFieldsContainer = _styledComponents.default.div(_templateObject6 || (_templateObject6 = (0, _taggedTemplateLiteral2.default)(["\n  min-height: calc(100% - 46px);\n"])));

var _default = EditorSidebar;
exports.default = _default;