"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _immer = _interopRequireDefault(require("immer"));

var _antd = require("antd");

var _icons = require("@ant-design/icons");

var _MediaImage = _interopRequireDefault(require("./MediaImage"));

var _utils = require("../utils");

var _actions = require("../actions");

var _store = require("../store");

var _theme = require("../theme");

var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6, _templateObject7, _templateObject8, _templateObject9, _templateObject10, _templateObject11;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2.default)(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

const MediaLibrary = props => {
  const {
    onSelect,
    allow = [],
    multiple,
    selected: defaultSelected = []
  } = props;
  const ref = (0, _react.useRef)();
  const isVisible = (0, _utils.useOnScreen)(ref);
  const [{
    config,
    cmsState: {
      siteID
    }
  }, dispatch] = (0, _store.useStore)();
  const [media, setMedia] = (0, _react.useState)({
    items: [],
    page: 0
  });
  const [activeFile, setActiveFile] = (0, _react.useState)(null);
  const [uploader, setUploader] = (0, _react.useState)(false);
  const [loading, setLoading] = (0, _react.useState)(false);
  const [selected, setSelected] = (0, _react.useState)(defaultSelected);
  const [search, setSearch] = (0, _react.useState)('');
  const activeFileIndex = activeFile && media.items.findIndex(o => o.id === activeFile.id);
  (0, _react.useEffect)(() => {
    isVisible && media.page > -1 && loadMediaItems(media.page);
  }, [isVisible]);

  const handleSearch = async value => {
    if (value) {
      const result = await _actions.mediaActions.getMediaItems({
        siteID,
        page: 0,
        search: value,
        limit: 24,
        allow
      }, dispatch, config);

      if (result) {
        setMedia({
          items: result.items,
          page: result.page
        });
      }
    } else {
      loadMediaItems(0, true);
    }
  };

  const loadMediaItems = async function loadMediaItems(page) {
    let clear = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    const result = await _actions.mediaActions.getMediaItems({
      siteID,
      page,
      limit: 24,
      allow
    }, dispatch, config);

    if (result) {
      setMedia({
        items: clear ? result.items : media.items.concat(result.items),
        page: result.page
      });
    }
  };

  const handleUpdateMediaItem = async mediaItem => {
    const {
      id,
      altText,
      siteID
    } = mediaItem;
    const result = await _actions.mediaActions.updateMediaItem({
      id,
      altText,
      siteID
    }, dispatch, config);

    if (result) {
      setMedia({
        items: media.items.map(o => o.id === result.id ? result : o),
        page: media.page
      });

      _antd.message.success("Saved successfully.");
    }
  };

  const handlDeleteMediaItem = async () => {
    const result = await _actions.mediaActions.deleteMediaItem(_objectSpread(_objectSpread({}, activeFile), {}, {
      siteID
    }), dispatch, config);

    if (result) {
      setMedia({
        items: items.filter(o => o.id !== parseInt(result)),
        page: media.page
      });
      handleCloseDialog();

      _antd.message.success("Deleted successfully.");
    }
  };

  const handleFileUpload = async info => {
    const {
      file: {
        status,
        name,
        originFileObj,
        error
      }
    } = info;

    if (status !== 'uploading') {
      setLoading(true);
      const result = await _actions.mediaActions.uploadMediaItem({
        siteID,
        file: originFileObj
      }, dispatch, config);

      if (result) {
        setMedia({
          items: [result, ...media.items],
          page: media.page
        });
      }
    }

    if (status === 'done') {
      _antd.message.success("".concat(name, " file uploaded successfully."));

      setLoading(false);
    } else if (status === 'error') {
      // TODO: length computable is set to false and therefore throwing an error if file size is too big.
      // However, this has nothing to do with the actual file upload to the backend, so we not gonna display an error here.
      // But this should be fixed at some point.
      if (!(error !== null && error !== void 0 && error.lengthComputable)) {
        _antd.message.success("".concat(name, " file uploaded successfully."));
      } else {
        console.log(info);

        _antd.message.error("".concat(name, " file upload failed."));
      }

      setLoading(false);
    }
  };

  const handleCloseDialog = () => {
    setActiveFile(null);
  };

  const handleClickCheckbox = image => {
    const nextSelection = (0, _immer.default)(selected, draft => {
      const index = selected.findIndex(o => o.id === image.id);

      if (index > -1) {
        draft.splice(index, 1);
      } else {
        draft.push(image);
      }

      return draft;
    });
    setSelected(nextSelection);
  };

  const handleSelect = item => {
    if (multiple) {
      handleClickCheckbox(item);
    } else {
      dispatch({
        type: 'CLOSE_DIALOG'
      });
      onSelect(item);
    }

    setActiveFile(null);
  };

  const handleSelectMultiple = () => {
    dispatch({
      type: 'CLOSE_DIALOG'
    });
    onSelect && onSelect(selected);
  };

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(Container, {
    actionBar: multiple && selected.length > 0
  }, /*#__PURE__*/_react.default.createElement(_antd.Space, {
    direction: "vertical",
    size: 20
  }, /*#__PURE__*/_react.default.createElement(_antd.PageHeader, {
    title: /*#__PURE__*/_react.default.createElement(_antd.Button, {
      icon: /*#__PURE__*/_react.default.createElement(_icons.UploadOutlined, null),
      children: "Upload",
      type: "primary",
      onClick: () => setUploader(!uploader),
      loading: loading
    }),
    extra: [/*#__PURE__*/_react.default.createElement(_antd.Input.Search, {
      key: "search",
      allowClear: true,
      value: search,
      onChange: e => setSearch(e.target.value),
      onSearch: handleSearch
    })]
  }), uploader && /*#__PURE__*/_react.default.createElement(_antd.Upload.Dragger, {
    name: "file",
    multiple: true,
    onChange: handleFileUpload,
    showUploadList: false
  }, /*#__PURE__*/_react.default.createElement("p", {
    className: "ant-upload-drag-icon"
  }, /*#__PURE__*/_react.default.createElement(_icons.InboxOutlined, null)), /*#__PURE__*/_react.default.createElement("p", {
    className: "ant-upload-text"
  }, "Click or drag file to this area to upload")), /*#__PURE__*/_react.default.createElement(MediaItems, null, media.items && media.items.map(o => {
    return /*#__PURE__*/_react.default.createElement(MediaItem, {
      key: o.id
    }, /*#__PURE__*/_react.default.createElement(MediaItemInner, {
      onClick: () => setActiveFile(o)
    }, (0, _utils.renderImage)(o)), multiple && /*#__PURE__*/_react.default.createElement(CheckboxContainer, {
      onClick: () => handleClickCheckbox(o)
    }, /*#__PURE__*/_react.default.createElement(_antd.Checkbox, {
      checked: !!selected.find(p => p.id === o.id)
    })));
  }), /*#__PURE__*/_react.default.createElement(DummyItem, null), /*#__PURE__*/_react.default.createElement(DummyItem, null), /*#__PURE__*/_react.default.createElement(DummyItem, null), /*#__PURE__*/_react.default.createElement(DummyItem, null), /*#__PURE__*/_react.default.createElement(DummyItem, null), /*#__PURE__*/_react.default.createElement(LoadingContainer, {
    ref: ref,
    key: 0,
    visible: media.page > -1
  }, /*#__PURE__*/_react.default.createElement(_antd.Spin, {
    size: "large"
  }))), multiple && selected.length > 0 && /*#__PURE__*/_react.default.createElement(ActionBar, null, "".concat(selected.length, " selected"), /*#__PURE__*/_react.default.createElement(_antd.Button, {
    onClick: handleSelectMultiple,
    children: "Select",
    type: "primary"
  })))), !!activeFile && /*#__PURE__*/_react.default.createElement(_antd.Modal, {
    transitionName: "none",
    maskTransitionName: "none",
    title: 'Media Image',
    visible: true,
    onCancel: handleCloseDialog,
    footer: null,
    width: 1024
  }, /*#__PURE__*/_react.default.createElement(PrevButton, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    icon: /*#__PURE__*/_react.default.createElement(_icons.ArrowLeftOutlined, null),
    onClick: () => setActiveFile(media.items[activeFileIndex - 1]),
    disabled: activeFileIndex === 0
  })), /*#__PURE__*/_react.default.createElement(_MediaImage.default, {
    file: activeFile,
    onSelect: onSelect && handleSelect,
    onDelete: handlDeleteMediaItem,
    onUpdate: handleUpdateMediaItem
  }), /*#__PURE__*/_react.default.createElement(NextButton, null, /*#__PURE__*/_react.default.createElement(_antd.Button, {
    icon: /*#__PURE__*/_react.default.createElement(_icons.ArrowRightOutlined, null),
    onClick: () => setActiveFile(media.items[activeFileIndex + 1]),
    disabled: activeFileIndex === media.items.length - 1
  }))));
};

const Container = _styledComponents.default.div(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  padding-bottom: ", ";\n"])), (_ref) => {
  let {
    actionBar
  } = _ref;
  return actionBar ? '40px' : 0;
});

const MediaItems = _styledComponents.default.div(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n  display: flex;\n  flex-wrap: wrap;\n  justify-content: space-between;\n"])));

const MediaItem = _styledComponents.default.div(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["\n  float: left;\n  position: relative;\n  height: 140px;\n  width: 140px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  margin-bottom: 20px;\n  cursor: pointer;\n  background: #fff;\n  border: 1px solid #d9d9d9;\n"])));

const MediaItemInner = _styledComponents.default.div(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["\n  height: 100%;\n  width: 100%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n\n  .gatsby-image-wrapper {\n    max-width: 100%;\n    max-height: 100%;\n  }\n"])));

const CheckboxContainer = _styledComponents.default.div(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["\n  position: absolute;\n  top: 4px;\n  right: 6px;\n  z-index: 1;\n  padding: 4px;\n"])));

const DummyItem = _styledComponents.default.div(_templateObject6 || (_templateObject6 = (0, _taggedTemplateLiteral2.default)(["\n  height: 0;\n  width: 140px;\n"])));

const LoadingContainer = _styledComponents.default.div(_templateObject7 || (_templateObject7 = (0, _taggedTemplateLiteral2.default)(["\n  width: 100%;\n  padding: 20px;\n  display: flex;\n  justify-content: center;\n  ", ";\n"])), (_ref2) => {
  let {
    visible
  } = _ref2;
  return !visible && (0, _styledComponents.css)(_templateObject8 || (_templateObject8 = (0, _taggedTemplateLiteral2.default)(["\n      opacity: 0;\n      height: 0;\n      padding: 0;\n    "])));
});

const ActionBar = _styledComponents.default.div(_templateObject9 || (_templateObject9 = (0, _taggedTemplateLiteral2.default)(["\n  position: absolute;\n  bottom: 0;\n  left: 0;\n  width: 100%;\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  padding: 20px;\n  background: #fff;\n  border-top: 1px solid ", ";\n"])), _theme.colors.tertiary);

const PrevButton = _styledComponents.default.div(_templateObject10 || (_templateObject10 = (0, _taggedTemplateLiteral2.default)(["\n  position: absolute;\n  z-index: 1;\n  top: 12px;\n  right: 100px;\n"])));

const NextButton = _styledComponents.default.div(_templateObject11 || (_templateObject11 = (0, _taggedTemplateLiteral2.default)(["\n  position: absolute;\n  z-index: 1;\n  top: 12px;\n  right: 60px;\n"])));

var _default = MediaLibrary;
exports.default = _default;